@@ -59,7 +59,8 @@ class AdbExt(object):
         :return:
         """
         if not self.is_helper_ready:
-            if 'adbui' not in self.util.shell('ls {}'.format(self.temp_device_dir_path)):
+            file_names = self.util.shell('ls {}'.format(self.temp_device_dir_path))
+            if 'adbui' not in file_names:
                 helper_path = os.path.join(self.dir_path, 'static', 'adbui')
                 self.push(helper_path, self.temp_device_dir_path)
             self.is_helper_ready = True
@@ -70,13 +71,15 @@ class AdbExt(object):
         self.util.shell('rm -rf {}'.format(path))
 
     def screenshot(self, pc_path=None):
-        out = self.run_helper_cmd('screenshot')
+        out = self.run_helper_cmd('screenshot1')
         if out and len(out) > 50:
             out = base64.b64decode(out)
         else:  # helper 截图失败，使用 screencap 截图
             logging.warning('helper 截图失败')
-            arg = 'adb -s {} exec-out screencap -p'.format(self.util.sn)
-            out = self.util.cmd(arg, encoding=None)  # 这里是 png bytes string
+            arg = 'exec-out screencap1 -p'.format(self.util.sn)
+            out = self.util.adb(arg, encoding=None)  # 这里是 png bytes string
+
+        print(type(out), 'tango')
 
         # 保存截图
         if pc_path:
